package com.muyu.quest.remote;

import com.muyu.common.core.domain.Result;
import com.muyu.quest.model.DataModel;
import com.muyu.quest.model.DataValueModel;
import com.muyu.quest.remote.factory.RemoteDataSourceFactory;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.cloud.openfeign.FeignClient;
import com.muyu.common.core.constant.ServiceNameConstants;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * @ Tool：IntelliJ IDEA
 * @ Author：胡杨
 * @ Date：2024-08-21-10:50
 * @ Version：1.0
 * @ Description：数据源远程调用
 * @Author: 胡杨
 */
@FeignClient(contextId = "RemoteDataSourceService",
        value = ServiceNameConstants.SOURCE_SERVICE,
        url = "http://10.0.2.1:19652/",
        fallbackFactory = RemoteDataSourceFactory.class)
public interface RemoteDataSourceService {

    @PostMapping("/value/findTableValue")
    public Result<List<List<DataModel>>> findTableValue(@RequestBody DataValueModel dataValueModel);

    /**
     * 根据基础表ID和SQL语句查询条数
     *
     * @param dataValueModel 基础表ID和sql语句
     * @return DataValue{kltv}
     */
    @PostMapping("/value/getTableValueTotal")
    public Result getTableValueTotal(@RequestBody DataValueModel dataValueModel);

    /**
     * 根据基础表ID和SQL语句查询数据
     *
     * @param dataValueModel 基础表ID和sql语句
     * @return DataValue{kltv}
     */
    @PostMapping("/value/addTableValue")
    public Result addTableValue(@RequestBody DataValueModel dataValueModel);
}
