package com.muyu.quest.controller;

import java.util.Arrays;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.quest.domain.TaskExport;
import com.muyu.quest.service.ITaskExportService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.security.utils.SecurityUtils;
import org.springframework.validation.annotation.Validated;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 任务执行记录Controller
 *
 * @Author: 胡杨
 * @date 2024-09-06
 */
@RestController
@RequestMapping("/export")
public class TaskExportController extends BaseController
{
    @Resource
    private ITaskExportService taskExportService;

    /**
     * 查询任务执行记录列表
     */
    @RequiresPermissions("quest:export:list")
    @GetMapping("/list")
    public Result<TableDataInfo<TaskExport>> list(TaskExport taskExport)
    {
        startPage();
        List<TaskExport> list = taskExportService.selectTaskExportList(taskExport);
        return getDataTable(list);
    }

    /**
     * 导出任务执行记录列表
     */
    @RequiresPermissions("quest:export:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TaskExport taskExport)
    {
        List<TaskExport> list = taskExportService.selectTaskExportList(taskExport);
        ExcelUtil<TaskExport> util = new ExcelUtil<TaskExport>(TaskExport.class);
        util.exportExcel(response, list, "任务执行记录数据");
    }

    /**
     * 获取任务执行记录详细信息
     */
    @RequiresPermissions("quest:export:query")
    @GetMapping(value = "/{id}")
    public Result<List<TaskExport>> getInfo(@PathVariable("id") Long id)
    {
        return success(taskExportService.selectTaskExportById(id));
    }

    /**
     * 新增任务执行记录
     */
    @RequiresPermissions("quest:export:add")
    @PostMapping
    public Result<Integer> add(
            @Validated @RequestBody TaskExport taskExport)
    {
        if (taskExportService.checkIdUnique(taskExport)) {
            return error("新增 任务执行记录 '" + taskExport + "'失败，任务执行记录已存在");
        }
        return toAjax(taskExportService.save(taskExport));
    }

    /**
     * 修改任务执行记录
     */
    @RequiresPermissions("quest:export:edit")
    @PutMapping
    public Result<Integer> edit(
            @Validated @RequestBody TaskExport taskExport)
    {
        if (!taskExportService.checkIdUnique(taskExport)) {
            return error("修改 任务执行记录 '" + taskExport + "'失败，任务执行记录不存在");
        }
        return toAjax(taskExportService.updateById(taskExport));
    }

    /**
     * 删除任务执行记录
     */
    @RequiresPermissions("quest:export:remove")
	@DeleteMapping("/{ids}")
    public Result<Integer> remove(@PathVariable("ids") Long[] ids)
    {
        taskExportService.removeBatchByIds(Arrays.asList(ids));
        return success();
    }


    @PostMapping("/selTaskStart")
    public Result selTaskStart(String taskCode){
        TaskExport taskExport = new TaskExport();
        taskExport.setTaskCode(taskCode);
        List<TaskExport> taskExports = taskExportService.selectTaskExportList(taskExport);
        int num = taskExports.size();
        int yNum = taskExports.stream().filter(taskExport1 -> taskExport1.getStart() == 1).toArray().length;
        int nNum = num - yNum;
        return success("共执行线程"+num+"个,完成"+yNum+"个,未完成"+nNum+"个");
    }
}
