package com.muyu.quest.job;

/**
 * @Author: 胡杨
 * @Name: TaskJob
 * @Description: 任务定时任务
 * @CreatedDate: 2024/9/4 下午2:37
 * @FilePath: com.muyu.quest.job
 */


import com.muyu.quest.domain.Node;
import com.muyu.quest.domain.NodeDisposition;
import com.muyu.quest.req.NodeReq;
import com.muyu.quest.req.TaskReq;
import com.muyu.quest.resp.TaskResp;
import com.muyu.quest.service.INodeDispositionService;
import com.muyu.quest.service.INodeService;
import com.muyu.quest.service.TaskService;
import com.xxl.job.core.handler.annotation.XxlJob;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @Author: 胡杨
 * @Name: TaskJob
 * @Description: 任务定时任务
 * @CreatedDate: 2024/9/4 下午2:37
 * @FilePath: com.muyu.quest.job
 */

@Component
public class TaskJob {

    @Resource
    private TaskService taskService;
    @Resource
    private INodeService nodeService;
    @Resource
    private INodeDispositionService nodeDispositionService;

    // 定时清理过期任务与其相关数据
    @XxlJob(value = "clearTask")
    public void clearTask() {
        List<TaskResp> tasks = taskService.selectTaskList(new TaskReq());
        List<Node> nodes = nodeService.selectNodeList(new NodeReq());
        List<NodeDisposition> dispositions = nodeDispositionService.selectNodeDispositionList(new NodeDisposition());

        // 查询节点表存在但任务表不存在的任务编码
        Set<String> notContainsTaskCodeList = nodes.
                stream().
                map(Node::getTaskCode).
                filter(nodeTaskCode -> !tasks.
                        stream().
                        map(TaskResp::getTaskCode).
                        toList().contains(nodeTaskCode)).
                collect(Collectors.toSet());
        // 删除相关节点表数据
        if (!notContainsTaskCodeList.isEmpty()) {
            nodeService.batchDelect(notContainsTaskCodeList.toArray(new String[0]));
        }
        // 查询配置表存在但节点表不存在的节点编码
        Set<String> notContainsNodeCodeList = dispositions.
                stream().
                map(NodeDisposition::getNodeCode).
                filter(nodeDispositionNodeCode -> !nodes.
                        stream().
                        map(Node::getNodeCode).
                        toList().contains(nodeDispositionNodeCode)).
                collect(Collectors.toSet());
        // 删除相关配置表数据
        if (!notContainsNodeCodeList.isEmpty()) {
            nodeDispositionService.batchDelect(notContainsNodeCodeList.toArray(new String[0]));
        }
    }

}
