package com.muyu.quest.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import org.springframework.stereotype.Service;
import com.muyu.quest.mapper.TaskExportMapper;
import com.muyu.quest.domain.TaskExport;
import com.muyu.quest.service.ITaskExportService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import org.springframework.util.Assert;

/**
 * 任务执行记录Service业务层处理
 *
 * @Author: 胡杨
 * @date 2024-09-06
 */
@Service
public class TaskExportServiceImpl
        extends ServiceImpl<TaskExportMapper, TaskExport>
        implements ITaskExportService {

    /**
     * 精确查询任务执行记录
     *
     * @param id 任务执行记录主键
     * @return 任务执行记录
     */
    @Override
    public TaskExport selectTaskExportById(Long id)
    {
        LambdaQueryWrapper<TaskExport> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(id, "id不可为空");
        queryWrapper.eq(TaskExport::getId, id);
        return this.getOne(queryWrapper);
    }


    /**
     * 查询任务执行记录列表
     *
     * @param taskExport 任务执行记录
     * @return 任务执行记录
     */
    @Override
    public List<TaskExport> selectTaskExportList(TaskExport taskExport)
    {
        LambdaQueryWrapper<TaskExport> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(taskExport.getTaskCode())){
            queryWrapper.eq(TaskExport::getTaskCode, taskExport.getTaskCode());
        }

        return this.list(queryWrapper);
    }

    /**
    * 唯一 判断
    * @param taskExport 任务执行记录
     * @return 任务执行记录
    */
    @Override
    public Boolean checkIdUnique(TaskExport taskExport) {
        LambdaQueryWrapper<TaskExport> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaskExport::getId, taskExport.getId());
        return this.count(queryWrapper) > 0;
    }

    @Override
    public TaskExport selectTaskExport(TaskExport taskExport) {
        LambdaQueryWrapper<TaskExport> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(taskExport.getTaskCode())){
            queryWrapper.eq(TaskExport::getTaskCode, taskExport.getTaskCode());
        }
        if (taskExport.getStart() != null){
            queryWrapper.eq(TaskExport::getStart, taskExport.getStart());
        }
        queryWrapper.last("limit 1");
        return this.getOne(queryWrapper);
    }

    @Override
    public void updateByExportCode(TaskExport taskExport) {
        LambdaUpdateWrapper<TaskExport> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(TaskExport::getExportCode, taskExport.getExportCode())
                .set(TaskExport::getError, taskExport.getError())
                .set(TaskExport::getStart, taskExport.getStart());
        this.update(null, updateWrapper);
    }

}
